@@ -7,8 +7,8 @@
 ;; Created: March 11, 2020
 ;; URL: https://github.com/shg/julia-vterm.el
 ;; Package-Requires: ((emacs "25.1") (vterm "0.0.1"))
-;; Package-Version: 0.27
-;; Package-Revision: 310fa8fc32e8
+;; Package-Version: 0.29
+;; Package-Revision: 1cf2958448df
 ;; Keywords: languages, julia
 
 ;; This file is not part of GNU Emacs.
@@ -170,10 +170,11 @@ If there's already an alive REPL buffer for the session, it will be opened."
 	  (setq julia-vterm-fellow-repl-buffer repl-buffer)
 	  (switch-to-buffer-other-window script-buffer)))))
 
-(defun julia-vterm-repl-restart ()
-  "Restart the inferior Julia process in the current REPL buffer."
-  (interactive)
-  (if (y-or-n-p "Restart Julia REPL? ")
+(defun julia-vterm-repl-restart (&optional arg)
+  "Restart the inferior Julia process in the current REPL buffer.
+With prefix ARG, restart immediately without the confirmation prompt."
+  (interactive "P")
+  (if (or arg (y-or-n-p "Restart Julia REPL? "))
       (julia-vterm-repl-buffer (julia-vterm-repl-session-name (current-buffer)) t)))
 
 (defun julia-vterm-repl-clear-buffer ()
@@ -218,7 +219,7 @@ Return a corresponding symbol or nil if not ready for input."
 This returns a list of the current working directory of the
 inferior Julia process and the current active environment."
   (with-current-buffer buf
-    (let ((uid (random #x100000000)))
+    (let ((uid (+ #x10000000 (random #xf0000000))))
       (vterm-send-return)
       (julia-vterm-paste-string
        (format (concat "\"$(string(%s, base = 16)):"
